@@ -7,6 +7,8 @@ class CC:
 
     description_id: Final[str] = 'description_id'
 
+    event: Final[str] = 'event'
+
     formatted_description: Final[str] = 'formatted_description'
 
     info: Final = 'info'
@@ -14,8 +16,13 @@ class CC:
     last_used_time: Final[str] = 'last_used_time'
     length: Final[str] = 'length'
 
+    note: Final[str] = 'note'
+
     plain_description: Final[str] = 'plain_description'
 
+    series: Final[str] = 'series'
+
     text: Final[str] = 'text'
 
+    update_time: Final[str] = 'update_time'
     used_count: Final[str] = 'used_count'
